@@ -45,3 +45,12 @@ def test_tags_update(tmpdir):
         assert src.tags() == {'a': '1', 'b': '2'}
         assert src.tags(1) == {'c': '3'}
         assert src.tags(ns='rasterio_testing') == {'rus': u'другая строка'}
+
+def test_tags_update_twice():
+    with rasterio.open(
+            'test.tif', 'w', 
+            'GTiff', 3, 4, 1, dtype=rasterio.ubyte) as dst:
+        dst.update_tags(a=1, b=2)
+        assert dst.tags() == {'a': '1', 'b': '2'}
+        dst.update_tags(c=3)
+        assert dst.tags() == {'a': '1', 'b': '2', 'c': '3'}
